@@ -1,6 +1,6 @@
 #' @rdname is_set_equal
 #' @export
-assert_is_set_equal <- function(x, y)
+assert_are_set_equal <- function(x, y)
 {
   assert_engine(
     x, 
@@ -11,6 +11,14 @@ assert_is_set_equal <- function(x, y)
   )
 }
 
+#' @rdname is_set_equal
+#' @export
+assert_is_set_equal <- function(x, y)
+{
+  .Deprecated("assert_are_set_equal")
+  assert_are_set_equal(x, y)
+}
+
 #' @rdname is_set_equal
 #' @export
 assert_is_subset <- function(x, y)
