@@ -2,7 +2,7 @@
 #' @export
 assert_all_are_in_future <- function(x)
 {                                                     
-  msg <- sprintf("%s are not all in the future.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all in the future.", get_name_in_parent(x))
   assert_engine(x, is_in_future, msg)  
 }
 
@@ -10,7 +10,7 @@ assert_all_are_in_future <- function(x)
 #' @export
 assert_any_are_in_future <- function(x)
 {                                                     
-  msg <- sprintf("%s are all in the past.", get_name_in_parent(x))
+  msg <- gettextf("%s are all in the past.", get_name_in_parent(x))
   assert_engine(x, is_in_future, msg, what = "any")  
 }
  
@@ -18,7 +18,7 @@ assert_any_are_in_future <- function(x)
 #' @export
 assert_all_are_in_past <- function(x)
 {                                                     
-  msg <- sprintf("%s are not all in the past.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all in the past.", get_name_in_parent(x))
   assert_engine(x, is_in_past, msg)  
 }
 
@@ -26,6 +26,6 @@ assert_all_are_in_past <- function(x)
 #' @export
 assert_any_are_in_past <- function(x)
 {                                                     
-  msg <- sprintf("%s are all in the future.", get_name_in_parent(x))
+  msg <- gettextf("%s are all in the future.", get_name_in_parent(x))
   assert_engine(x, is_in_past, msg, what = "any")  
 }
