@@ -226,6 +226,10 @@ has_names <- function(x, .xname = get_name_in_parent(x))
   {
     return(false("The names of %s are NULL.", .xname))
   }
+  if(!any(nzchar(namesx))) 
+  {
+    return(false("The names of %s are all empty.", .xname))
+  }
   TRUE
 } 
 
