@@ -3,10 +3,14 @@
 is_in_future <- function(x)
 {
   x <- coerce_to(x, "POSIXct")
-  ok <- rep.int(TRUE, length(x))
-  ok[x <= Sys.time()] <- FALSE
-  names(ok) <- x
-  ok
+  call_and_name(
+    function(x)
+    {
+      ok <- x > Sys.time()
+      set_cause(ok, "in past")
+    },
+    x
+  )
 }
 
 #' Is the input in the past/future?
@@ -20,8 +24,14 @@ is_in_future <- function(x)
 #' \code{FALSE}.
 #' @details The current time is determined by \code{Sys.time}, and the 
 #' input is coerced to \code{POSIXct} format if necessary.
+#' @note Note that the print method for \code{POSIXct} objects means that the
+#' cause attribute (in the event of failures) is not shown.  You can still 
+#' access it via, e.g., \code{cause(is_in_past(x))}.
 #' @seealso \code{\link{Sys.time}}.
 #' @examples
+#' x <- Sys.time() + c(-1, 100)
+#' is_in_past(x)
+#' is_in_future(x)
 #' assert_is_empty(NULL)
 #' assert_is_empty(numeric())
 #' assert_is_non_empty(1:10)
@@ -33,8 +43,12 @@ is_in_future <- function(x)
 is_in_past <- function(x)
 {
   x <- coerce_to(x, "POSIXct")
-  ok <- rep.int(TRUE, length(x))
-  ok[x >= Sys.time()] <- FALSE
-  names(ok) <- x
-  ok
+  call_and_name(
+    function(x)
+    {
+      ok <- x < Sys.time()
+      set_cause(ok, "in future")
+    },
+    x
+  )
 }
